@@ -5,9 +5,10 @@ use warnings;
 package Log::Any;
 
 # ABSTRACT: Bringing loggers and listeners together
-our $VERSION = '1.038';
+our $VERSION = '1.048';
 
 use Log::Any::Manager;
+use Log::Any::Proxy::Null;
 use Log::Any::Adapter::Util qw(
   require_dynamic
   detection_aliases
@@ -44,8 +45,8 @@ sub _export_to_caller {
     my $saw_log_param;
     my @params;
     while ( my $param = shift @_ ) {
-        if ( $param eq '$log' ) {
-            $saw_log_param = 1;    # defer until later
+        if ( !$saw_log_param && $param =~ /^\$(\w+)/ ) {
+            $saw_log_param = $1;   # defer until later
             next;                  # singular
         }
         else {
@@ -59,10 +60,10 @@ sub _export_to_caller {
     }
 
     # get logger if one was requested
-    if ($saw_log_param) {
+    if ( defined $saw_log_param ) {
         no strict 'refs';
         my $proxy = $class->get_logger( category => $caller, @params );
-        my $varname = "$caller\::log";
+        my $varname = "${caller}::${saw_log_param}";
         *$varname = \$proxy;
     }
 }
@@ -76,7 +77,18 @@ sub get_logger {
       defined $params{category} ? delete $params{'category'} : caller;
 
     if ( my $default = delete $params{'default_adapter'} ) {
-        $class->_manager->set_default( $category, $default );
+        my @default_adapter_params = ();
+        if (ref $default eq 'ARRAY') {
+            ($default, @default_adapter_params) = @{ $default };
+        }
+        # Every default adapter is set only for a given logger category.
+        # When another adapter is configured (by using
+        # Log::Any::Adapter->set) for this category, it takes
+        # precedence, but if that adapter is later removed, the default
+        # we set here takes over again.
+        $class->_manager->set_default(
+            $category, $default, @default_adapter_params
+        );
     }
 
     my $adapter = $class->_manager->get_adapter( $category );
@@ -91,7 +103,8 @@ sub _get_proxy_class {
     my ( $self, $proxy_name ) = @_;
     return $Log::Any::OverrideDefaultProxyClass
       if $Log::Any::OverrideDefaultProxyClass;
-    return "Log::Any::Proxy" unless $proxy_name;
+    return "Log::Any::Proxy" if !$proxy_name && _manager->has_consumer;
+    return "Log::Any::Proxy::Null" if !$proxy_name;
     my $proxy_class = (
           substr( $proxy_name, 0, 1 ) eq '+'
         ? substr( $proxy_name, 1 )
@@ -120,7 +133,7 @@ Log::Any - Bringing loggers and listeners together
 
 =head1 VERSION
 
-version 1.038
+version 1.048
 
 =head1 SYNOPSIS
 
@@ -135,6 +148,9 @@ In a CPAN or other module:
     # log a string and data using a formatting filter
     $log->debugf("arguments are: %s", \@_);
 
+    # log an error and throw an exception
+    die $log->fatal("a fatal error occurred");
+
 In a Moo/Moose-based module:
 
     package Foo;
@@ -198,14 +214,6 @@ whether the application has chosen (or will ever choose) a logging mechanism.
 See L<http://www.openswartz.com/2007/09/06/standard-logging-api/> for the
 original post proposing this module.
 
-=head1 NAME
-
-Log::Any - Bringing loggers and listeners together
-
-=head1 VERSION
-
-version 1.038
-
 =head1 LOG LEVELS
 
 C<Log::Any> supports the following log levels and aliases, which is meant to be
@@ -274,6 +282,9 @@ To log a message, pass a single string to any of the log levels or aliases. e.g.
     $log->warn("this is a warning");
     $log->warning("this is also a warning");
 
+The log string will be returned so that it can be used further (e.g. for a C<die> or
+C<warn> call).
+
 You should B<not> include a newline in your message; that is the responsibility
 of the logging mechanism, which may or may not want the newline.
 
@@ -323,13 +334,22 @@ detection methods.
 
 =head2 Setting an alternate default logger
 
-To choose something other than Null as the default, pass it as a parameter when
-loading C<Log::Any>
+When no other adapters are configured for your logger, C<Log::Any> uses
+the C<default_adapter>. To choose something other than Null as the
+default, pass it as a parameter when loading C<Log::Any>
 
     use Log::Any '$log', default_adapter => 'Stderr';
 
 The name of the default class follows the same rules as used by L<Log::Any::Adapter>.
 
+To pass arguments to the default adapter's constructor, use an arrayref:
+
+    use Log::Any '$log', default_adapter => [ 'File' => '/var/log/mylog.log' ];
+
+When a consumer configures their own adapter, the default adapter will be
+overridden. If they later remove their adapter, the default adapter will be
+used again.
+
 =head2 Configuring the proxy
 
 Any parameter passed on the import line or via the C<get_logger> method
@@ -390,25 +410,6 @@ other niceties.
 
 =back
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
-
-=head1 SUPPORT
-
-=head2 Bugs / Feature Requests
-
-Please report any bugs or feature requests through the issue tracker
-at L<https://github.com/dagolden/Log-Any/issues>.
-You will be notified automatically of any progress on your issue.
-
-=head2 Source Code
-
-This is open source software.  The code repository is available for
-public review and contribution under the terms of the license.
-
-L<https://github.com/dagolden/Log-Any>
-
-  git clone https://github.com/dagolden/Log-Any.git
-
 =head1 AUTHORS
 
 =over 4
@@ -421,21 +422,41 @@ Jonathan Swartz <swartz@pobox.com>
 
 David Golden <dagolden@cpan.org>
 
+=item *
+
+Doug Bell <preaction@cpan.org>
+
+=item *
+
+Daniel Pittman <daniel@rimspace.net>
+
+=item *
+
+Stephen Thirlwall <sdt@cpan.org>
+
 =back
 
 =head1 CONTRIBUTORS
 
-=for stopwords cm-perl David Golden Maxim Vuets Stephen Thirlwall
+=for stopwords bj5004 cm-perl Lucas Kanashiro Maros Kollar Maxim Vuets mephinet Philipp Gortan Stephen Thirlwall
 
 =over 4
 
 =item *
 
+bj5004 <bartosz.jakubski@hurra.com>
+
+=item *
+
 cm-perl <cm-perl@users.noreply.github.com>
 
 =item *
 
-David Golden <xdg@xdg.me>
+Lucas Kanashiro <kanashiro.duarte@gmail.com>
+
+=item *
+
+Maros Kollar <maros.kollar@geizhals.at>
 
 =item *
 
@@ -443,77 +464,25 @@ Maxim Vuets <maxim.vuets@booking.com>
 
 =item *
 
-Stephen Thirlwall <sdt@dr.com>
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2014 by Jonathan Swartz and David Golden.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
-
-=head1 SUPPORT
-
-=head2 Bugs / Feature Requests
-
-Please report any bugs or feature requests through the issue tracker
-at L<https://github.com/dagolden/Log-Any/issues>.
-You will be notified automatically of any progress on your issue.
-
-=head2 Source Code
-
-This is open source software.  The code repository is available for
-public review and contribution under the terms of the license.
-
-L<https://github.com/dagolden/Log-Any>
-
-  git clone https://github.com/dagolden/Log-Any.git
-
-=head1 AUTHORS
-
-=over 4
+mephinet <mephinet@gmx.net>
 
 =item *
 
-Jonathan Swartz <swartz@pobox.com>
-
-=item *
-
-David Golden <dagolden@cpan.org>
-
-=back
-
-=head1 CONTRIBUTORS
-
-=for stopwords cm-perl David Golden Maxim Vuets Stephen Thirlwall
-
-=over 4
-
-=item *
-
-cm-perl <cm-perl@users.noreply.github.com>
-
-=item *
-
-David Golden <xdg@xdg.me>
-
-=item *
-
-Maxim Vuets <maxim.vuets@booking.com>
+Philipp Gortan <philipp.gortan@apa.at>
 
 =item *
 
 Stephen Thirlwall <sdt@dr.com>
 
+=item *
+
+Stephen Thirlwall <stephen.thirlwall@strategicdata.com.au>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Jonathan Swartz and David Golden.
+This software is copyright (c) 2017 by Jonathan Swartz, David Golden, and Doug Bell.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
