@@ -5,9 +5,10 @@ use warnings;
 package Log::Any::Adapter;
 
 # ABSTRACT: Tell Log::Any where to send its logs
-our $VERSION = '1.040';
+our $VERSION = '1.048';
 
 use Log::Any;
+our @CARP_NOT = ( 'Log::Any::Manager' );
 
 sub import {
     my $pkg = shift;
@@ -38,7 +39,7 @@ Log::Any::Adapter - Tell Log::Any where to send its logs
 
 =head1 VERSION
 
-version 1.040
+version 1.048
 
 =head1 SYNOPSIS
 
@@ -199,17 +200,10 @@ C<Log::Any> maintains a stack of entries created via C<set>.  If you call
 C<set> repeatedly, you will leak memory unless you do one of the
 following:
 
-=over 4
-
-=item *
-
-call C<remove> on the adapter returned from C<set> when you are done with it
-
-=item *
-
-use the C<lexically> feature to set a guard variable that will clean it up when it goes out of scope
-
-=back
+=for :list * call C<remove> on the adapter returned from C<set> when you are done with
+  it
+* use the C<lexically> feature to set a guard variable that will clean it
+  up when it goes out of scope
 
 When getting a logger for a particular category, C<Log::Any> will work its way
 down the stack and use the first matching entry.
@@ -243,11 +237,23 @@ Jonathan Swartz <swartz@pobox.com>
 
 David Golden <dagolden@cpan.org>
 
+=item *
+
+Doug Bell <preaction@cpan.org>
+
+=item *
+
+Daniel Pittman <daniel@rimspace.net>
+
+=item *
+
+Stephen Thirlwall <sdt@cpan.org>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Jonathan Swartz and David Golden.
+This software is copyright (c) 2017 by Jonathan Swartz, David Golden, and Doug Bell.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
