@@ -4,7 +4,8 @@ use warnings;
 
 package Log::Any::Adapter::Base;
 
-our $VERSION = '1.045';
+our $VERSION = '1.048';
+our @CARP_NOT = ( 'Log::Any::Adapter' );
 
 # we import these in case any legacy adapter uses them as class methods
 use Log::Any::Adapter::Util qw/make_method dump_one_line/;
@@ -51,7 +52,7 @@ Log::Any::Adapter::Base
 
 =head1 VERSION
 
-version 1.045
+version 1.048
 
 =head1 AUTHORS
 
@@ -69,11 +70,19 @@ David Golden <dagolden@cpan.org>
 
 Doug Bell <preaction@cpan.org>
 
+=item *
+
+Daniel Pittman <daniel@rimspace.net>
+
+=item *
+
+Stephen Thirlwall <sdt@cpan.org>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Jonathan Swartz, David Golden, and Doug Bell.
+This software is copyright (c) 2017 by Jonathan Swartz, David Golden, and Doug Bell.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
