@@ -5,7 +5,7 @@ use warnings;
 package Log::Any::Adapter::File;
 
 # ABSTRACT: Simple adapter for logging to files
-our $VERSION = '1.040';
+our $VERSION = '1.048';
 
 use Config;
 use Fcntl qw/:flock/;
@@ -25,11 +25,15 @@ sub new {
 
 sub init {
     my $self = shift;
-    if ( exists $self->{log_level} ) {
-        $self->{log_level} = Log::Any::Adapter::Util::numeric_level( $self->{log_level} )
-            unless $self->{log_level} =~ /^\d+$/;
+    if ( exists $self->{log_level} && $self->{log_level} =~ /\D/ ) {
+        my $numeric_level = Log::Any::Adapter::Util::numeric_level( $self->{log_level} );
+        if ( !$numeric_level ) {
+            require Carp;
+            Carp::carp( sprintf 'Invalid log level "%s". Defaulting to "%s"', $self->{log_level}, 'trace' );
+        }
+        $self->{log_level} = $numeric_level;
     }
-    else {
+    if ( !$self->{log_level} ) {
         $self->{log_level} = $trace_level;
     }
     my $file = $self->{file};
@@ -76,7 +80,7 @@ Log::Any::Adapter::File - Simple adapter for logging to files
 
 =head1 VERSION
 
-version 1.040
+version 1.048
 
 =head1 SYNOPSIS
 
@@ -124,11 +128,23 @@ Jonathan Swartz <swartz@pobox.com>
 
 David Golden <dagolden@cpan.org>
 
+=item *
+
+Doug Bell <preaction@cpan.org>
+
+=item *
+
+Daniel Pittman <daniel@rimspace.net>
+
+=item *
+
+Stephen Thirlwall <sdt@cpan.org>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Jonathan Swartz and David Golden.
+This software is copyright (c) 2017 by Jonathan Swartz, David Golden, and Doug Bell.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
