@@ -5,7 +5,7 @@ use warnings;
 package Log::Any::Adapter::Util;
 
 # ABSTRACT: Common utility functions for Log::Any
-our $VERSION = '1.040';
+our $VERSION = '1.048';
 
 use Exporter;
 our @ISA = qw/Exporter/;
@@ -125,7 +125,7 @@ sub detection_aliases             { @detection_aliases }
 sub numeric_level {
     my ($level) = @_;
     my $canonical =
-      exists $LOG_LEVEL_ALIASES{$level} ? $LOG_LEVEL_ALIASES{$level} : $level;
+      exists $LOG_LEVEL_ALIASES{ lc $level } ? $LOG_LEVEL_ALIASES{ lc $level } : $level;
     return $LOG_LEVELS{ uc($canonical) };
 }
 
@@ -241,7 +241,7 @@ Log::Any::Adapter::Util - Common utility functions for Log::Any
 
 =head1 VERSION
 
-version 1.040
+version 1.048
 
 =head1 DESCRIPTION
 
@@ -249,6 +249,63 @@ This module has utility functions to help develop L<Log::Any::Adapter>
 subclasses or L<Log::Any::Proxy> formatters/filters.  It also has some
 functions used in internal testing.
 
+=func logging_methods
+
+Returns a list of all logging method. E.g. "trace", "info", etc.
+
+=func detection_methods
+
+Returns a list of detection methods.  E.g. "is_trace", "is_info", etc.
+
+=func logging_and_detection_methods
+
+Returns a list of logging and detection methods (but not aliases).
+
+=func log_level_aliases
+
+Returns key/value pairs mapping aliases to "official" names.  E.g. "err" maps
+to "error".
+
+=func logging_aliases
+
+Returns a list of logging alias names.  These are the keys from
+L</log_level_aliases>.
+
+=func detection_aliases
+
+Returns a list of detection aliases.  E.g. "is_err", "is_fatal", etc.
+
+=func numeric_level
+
+Given a level name (or alias), returns the numeric value described above under
+log level constants.  E.g. "err" would return 3.
+
+=func dump_one_line
+
+Given a reference, returns a one-line L<Data::Dumper> dump with keys sorted.
+
+=func make_method
+
+Given a method name, a code reference and a package name, installs the code
+reference as a method in the package.
+
+=func require_dynamic (DEPRECATED)
+
+Given a class name, attempts to load it via require unless the class
+already has a constructor available.  Throws an error on failure. Used
+internally and may become private in the future.
+
+=func read_file (DEPRECATED)
+
+Slurp a file.  Does *not* apply any layers.  Used for testing and may
+become private in the future.
+
+=func cmp_deeply (DEPRECATED)
+
+Compares L<dump_one_line> results for two references.  Also takes a test
+label as a third argument.  Used for testing and may become private in the
+future.
+
 =head1 USAGE
 
 Nothing is exported by default.
@@ -268,65 +325,6 @@ constants will be imported:
     DEBUG     => 7
     TRACE     => 8
 
-=head1 FUNCTIONS
-
-=head2 logging_methods
-
-Returns a list of all logging method. E.g. "trace", "info", etc.
-
-=head2 detection_methods
-
-Returns a list of detection methods.  E.g. "is_trace", "is_info", etc.
-
-=head2 logging_and_detection_methods
-
-Returns a list of logging and detection methods (but not aliases).
-
-=head2 log_level_aliases
-
-Returns key/value pairs mapping aliases to "official" names.  E.g. "err" maps
-to "error".
-
-=head2 logging_aliases
-
-Returns a list of logging alias names.  These are the keys from
-L</log_level_aliases>.
-
-=head2 detection_aliases
-
-Returns a list of detection aliases.  E.g. "is_err", "is_fatal", etc.
-
-=head2 numeric_level
-
-Given a level name (or alias), returns the numeric value described above under
-log level constants.  E.g. "err" would return 3.
-
-=head2 dump_one_line
-
-Given a reference, returns a one-line L<Data::Dumper> dump with keys sorted.
-
-=head2 make_method
-
-Given a method name, a code reference and a package name, installs the code
-reference as a method in the package.
-
-=head2 require_dynamic (DEPRECATED)
-
-Given a class name, attempts to load it via require unless the class
-already has a constructor available.  Throws an error on failure. Used
-internally and may become private in the future.
-
-=head2 read_file (DEPRECATED)
-
-Slurp a file.  Does *not* apply any layers.  Used for testing and may
-become private in the future.
-
-=head2 cmp_deeply (DEPRECATED)
-
-Compares L<dump_one_line> results for two references.  Also takes a test
-label as a third argument.  Used for testing and may become private in the
-future.
-
 =head1 AUTHORS
 
 =over 4
@@ -339,11 +337,23 @@ Jonathan Swartz <swartz@pobox.com>
 
 David Golden <dagolden@cpan.org>
 
+=item *
+
+Doug Bell <preaction@cpan.org>
+
+=item *
+
+Daniel Pittman <daniel@rimspace.net>
+
+=item *
+
+Stephen Thirlwall <sdt@cpan.org>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Jonathan Swartz and David Golden.
+This software is copyright (c) 2017 by Jonathan Swartz, David Golden, and Doug Bell.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
