@@ -5,9 +5,10 @@ use warnings;
 package Log::Any::Proxy;
 
 # ABSTRACT: Log::Any generator proxy object
-our $VERSION = '1.040';
+our $VERSION = '1.048';
 
 use Log::Any::Adapter::Util ();
+use overload;
 
 sub _default_formatter {
     my ( $cat, $lvl, $format, @params ) = @_;
@@ -15,9 +16,18 @@ sub _default_formatter {
     my @new_params =
       map {
            !defined($_) ? '<undef>'
-          : ref($_)     ? Log::Any::Adapter::Util::dump_one_line($_)
+          : ref($_)     ? (
+            overload::OverloadedStringify($_) ? "$_"
+          : Log::Any::Adapter::Util::dump_one_line($_)
+        )
           : $_
       } @params;
+    # Perl 5.22 adds a 'redundant' warning if the number parameters exceeds
+    # the number of sprintf placeholders.  If a user does this, the warning
+    # is issued from here, which isn't very helpful.  Doing something
+    # clever would be expensive, so instead we just disable warnings for
+    # the final line of this subroutine.
+    no warnings;
     return sprintf( $format, @new_params );
 }
 
@@ -37,6 +47,11 @@ sub new {
     return $self;
 }
 
+sub clone {
+    my $self = shift;
+    return (ref $self)->new( %{ $self }, @_ );
+}
+
 sub init { }
 
 for my $attr (qw/adapter filter formatter prefix/) {
@@ -62,13 +77,16 @@ foreach my $name ( Log::Any::Adapter::Util::logging_methods(), keys(%aliases) )
     *{$name} = sub {
         my ( $self, @parts ) = @_;
         my $message = join(" ", grep { defined($_) && length($_) } @parts );
-        return unless length $message;
-        $message = $self->{filter}->( $self->{category}, $numeric, $message )
-          if defined $self->{filter};
-        return unless defined $message and length $message;
-        $message = "$self->{prefix}$message"
-          if defined $self->{prefix} && length $self->{prefix};
-        return $self->{adapter}->$realname($message);
+        if ( length $message ) {
+            $message = $self->{filter}->( $self->{category}, $numeric, $message )
+              if defined $self->{filter};
+            if ( defined $message and length $message ) {
+                $message = "$self->{prefix}$message"
+                  if defined $self->{prefix} && length $self->{prefix};
+                $self->{adapter}->$realname($message);
+            }
+        }
+        return $message if defined wantarray;
     };
     *{$namef} = sub {
         my ( $self, @args ) = @_;
@@ -97,7 +115,7 @@ Log::Any::Proxy - Log::Any generator proxy object
 
 =head1 VERSION
 
-version 1.040
+version 1.048
 
 =head1 SYNOPSIS
 
@@ -114,131 +132,14 @@ version 1.040
         String::Flogger::flog( @args );
     };
 
+    # create a clone with different attributes
+    my $bar_log = $log->clone( prefix => 'bar: ' );
+
 =head1 DESCRIPTION
 
 Log::Any::Proxy objects are what modules use to produce log messages.  They
 construct messages and pass them along to a configured adapter.
 
-=head1 USAGE
-
-=head2 Simple logging
-
-Your library can do simple logging using logging methods corresponding to
-the log levels (or aliases):
-
-=over 4
-
-=item *
-
-trace
-
-=item *
-
-debug
-
-=item *
-
-info (inform)
-
-=item *
-
-notice
-
-=item *
-
-warning (warn)
-
-=item *
-
-error (err)
-
-=item *
-
-critical (crit, fatal)
-
-=item *
-
-alert
-
-=item *
-
-emergency
-
-=back
-
-Pass a string to be logged.  Do not include a newline.
-
-    $log->info("Got some new for you.");
-
-The log string will be transformed via the C<filter> attribute (if any) and
-the C<prefix> (if any) will be prepended.
-
-B<NOTE>: While you are encouraged to pass a single string to be logged, if
-multiple arguments are passed, they are concatenated with a space character
-into a single string before processing.  This ensures consistency across
-adapters, some of which may support multiple arguments to their logging
-functions (and which concatenate in different ways) and some of which do
-not.
-
-=head2 Advanced logging
-
-Your library can do advanced logging using logging methods corresponding to
-the log levels (or aliases), but with an "f" appended:
-
-=over 4
-
-=item *
-
-tracef
-
-=item *
-
-debugf
-
-=item *
-
-infof (informf)
-
-=item *
-
-noticef
-
-=item *
-
-warningf (warnf)
-
-=item *
-
-errorf (errf)
-
-=item *
-
-criticalf (critf, fatalf)
-
-=item *
-
-alertf
-
-=item *
-
-emergencyf
-
-=back
-
-When these methods are called, the adapter is first checked to see if it is
-logging at that level.  If not, the method returns without logging.
-
-Next, arguments are transformed to a message string via the C<formatter>
-attribute.
-
-The default formatter first checks if the first log argument is a code
-reference.  If so, it will executed and the result used as the formatted
-message. Otherwise, the formatter acts like C<sprintf> with some helpful
-formatting.
-
-Finally, the message string is logged via the simple logging functions,
-which can transform or prefix as described above.
-
 =head1 ATTRIBUTES
 
 =head2 adapter
@@ -284,27 +185,122 @@ be logged.
 
 The default formatter does the following:
 
-=over 4
-
-=item *
-
-if the first argument is a code reference, it is executed and the result returned
-
-=item *
-
-otherwise, it acts like C<sprintf>, except that undef arguments are changed to C<< <undef> >> and any references or objects are dumped via L<Data::Dumper> (but without newlines).
-
-=back
-
-Numeric levels range from 0 (emergency) to 8 (trace).  Constant functions
-for these levels are available from L<Log::Any::Adapter::Util>.
-
 =head2 prefix
 
 If defined, this string will be prepended to all messages.  It will not
 include a trailing space, so add that yourself if you want.  This is less
 flexible/powerful than L</filter>, but avoids an extra function call.
 
+=head1 USAGE
+
+=head2 Simple logging
+
+Your library can do simple logging using logging methods corresponding to
+the log levels (or aliases):
+
+=for :list * trace
+* debug
+* info (inform)
+* notice
+* warning (warn)
+* error (err)
+* critical (crit, fatal)
+* alert
+* emergency
+
+Pass a string to be logged.  Do not include a newline.
+
+    $log->info("Got some new for you.");
+
+The log string will be transformed via the C<filter> attribute (if any) and
+the C<prefix> (if any) will be prepended. Returns the transformed log string.
+
+B<NOTE>: While you are encouraged to pass a single string to be logged, if
+multiple arguments are passed, they are concatenated with a space character
+into a single string before processing.  This ensures consistency across
+adapters, some of which may support multiple arguments to their logging
+functions (and which concatenate in different ways) and some of which do
+not.
+
+=head2 Advanced logging
+
+Your library can do advanced logging using logging methods corresponding to
+the log levels (or aliases), but with an "f" appended:
+
+=for :list * tracef
+* debugf
+* infof (informf)
+* noticef
+* warningf (warnf)
+* errorf (errf)
+* criticalf (critf, fatalf)
+* alertf
+* emergencyf
+
+When these methods are called, the adapter is first checked to see if it is
+logging at that level.  If not, the method returns without logging.
+
+Next, arguments are transformed to a message string via the C<formatter>
+attribute.
+
+The default formatter first checks if the first log argument is a code
+reference.  If so, it will executed and the result used as the formatted
+message. Otherwise, the formatter acts like C<sprintf> with some helpful
+formatting.
+
+Finally, the message string is logged via the simple logging functions,
+which can transform or prefix as described above. The transformed log
+string is then returned.
+
+=for :list * if the first argument is a code reference, it is executed and the result
+  returned
+* otherwise, it acts like C<sprintf>, except that undef arguments are
+  changed to C<< <undef> >> and any references or objects are dumped via
+  L<Data::Dumper> (but without newlines).
+
+Numeric levels range from 0 (emergency) to 8 (trace).  Constant functions
+for these levels are available from L<Log::Any::Adapter::Util>.
+
+=head1 TIPS
+
+=head2 UTF-8 in Data Structures
+
+If you have high-bit characters in a data structure being passed to a log
+method, Log::Any will output that data structure with the high-bit
+characters encoded as C<\x{###}>, Perl's escape sequence for high-bit
+characters. This is because the L<Data::Dumper> module escapes those
+characters.
+
+    use utf8;
+    use Log::Any qw( $log );
+    my @data = ( "Привет мир" ); # Hello, World!
+    $log->infof("Got: %s", \@data);
+    # Got: ["\x{41f}\x{440}\x{438}\x{432}\x{435}\x{442} \x{43c}\x{438}\x{440}"]
+
+If you want to instead display the actual characters in your log file or
+terminal, you can use the L<Data::Dumper::AutoEncode> module. To wire this
+up into Log::Any, you must pass a custom C<formatter> sub:
+
+    use utf8;
+    use Data::Dumper::AutoEncode;
+
+    sub log_formatter {
+        my ( $category, $level, $format, @params ) = @_;
+        # Run references through Data::Dumper::AutoEncode
+        @params = map { ref $_ ? eDumper( $_ ) : $_ } @params;
+        return sprintf $format, @params;
+    }
+
+    use Log::Any '$log', formatter => \&log_formatter;
+
+This formatter changes the output to:
+
+	Got: $VAR1 = [
+			  'Привет мир'
+			];
+
+Thanks to L<@denis-it|https://github.com/denis-it> for this tip!
+
 =head1 AUTHORS
 
 =over 4
@@ -317,11 +313,23 @@ Jonathan Swartz <swartz@pobox.com>
 
 David Golden <dagolden@cpan.org>
 
+=item *
+
+Doug Bell <preaction@cpan.org>
+
+=item *
+
+Daniel Pittman <daniel@rimspace.net>
+
+=item *
+
+Stephen Thirlwall <sdt@cpan.org>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Jonathan Swartz and David Golden.
+This software is copyright (c) 2017 by Jonathan Swartz, David Golden, and Doug Bell.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
