@@ -5,7 +5,7 @@ use warnings;
 package Log::Any::Test;
 
 # ABSTRACT: Test what you're logging with Log::Any
-our $VERSION = '1.042';
+our $VERSION = '1.048';
 
 no warnings 'once';
 $Log::Any::OverrideDefaultAdapterClass = 'Log::Any::Adapter::Test';
@@ -25,7 +25,7 @@ Log::Any::Test - Test what you're logging with Log::Any
 
 =head1 VERSION
 
-version 1.042
+version 1.048
 
 =head1 SYNOPSIS
 
@@ -142,11 +142,19 @@ David Golden <dagolden@cpan.org>
 
 Doug Bell <preaction@cpan.org>
 
+=item *
+
+Daniel Pittman <daniel@rimspace.net>
+
+=item *
+
+Stephen Thirlwall <sdt@cpan.org>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Jonathan Swartz, David Golden, and Doug Bell.
+This software is copyright (c) 2017 by Jonathan Swartz, David Golden, and Doug Bell.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
